﻿using LineUpTool2.DomainModel.Entities;
using Prism.Mvvm;
using System;
using System.Collections.ObjectModel;

namespace InfragisticsCalendarTest.ViewModels
{
    public class MainWindowViewModel : BindableBase
    {
        private string _initialCalendarIds;
        public string InitialCalendarIds
        {
            get { return _initialCalendarIds; }
            set { SetProperty(ref _initialCalendarIds, value); }
        } 

        // these are the resources
        private ObservableCollection<T_LINEDOWNDEVICES> _devices;
        public ObservableCollection<T_LINEDOWNDEVICES> Devices
        {
            get { return _devices; }
            set { SetProperty(ref _devices, value); }
        }

        // these are the appointments
        private ObservableCollection<T_LINEDOWNEVENTS> _events;
        public ObservableCollection<T_LINEDOWNEVENTS> Events
        {
            get { return _events; }
            set { SetProperty(ref _events, value); }
        }

        public MainWindowViewModel()
        {
            InitialCalendarIds = "2,1";

            InitializeData();
        }

        private void InitializeData()
        {
            T_LINEDOWNDEVICES deviceA = new T_LINEDOWNDEVICES
            {
                ANZEIGEWERT = "Device A",
                KALENDERFARBE = "#0000FF",
                LDD_ID = 1,
                T_LINEDOWNEVENTS = new ObservableCollection<T_LINEDOWNEVENTS>()
            };

            T_LINEDOWNDEVICES deviceB = new T_LINEDOWNDEVICES
            {
                ANZEIGEWERT = "Device B",
                KALENDERFARBE = "#00FF00",
                LDD_ID = 2,
                T_LINEDOWNEVENTS = new ObservableCollection<T_LINEDOWNEVENTS>()
            };

            Devices = new ObservableCollection<T_LINEDOWNDEVICES>
            {
                deviceA, deviceB
            };

            Events = new ObservableCollection<T_LINEDOWNEVENTS>
            {
                new T_LINEDOWNEVENTS
                {
                    START_DATE = DateTime.Now.AddHours(1),
                    KOMMENTAR = "Big Problem A-1",
                    LDE_ID = 1,
                    LDD_LDD_ID = 1,
                    END_DATE = DateTime.Now.AddHours(2),
                    T_LINEDOWNDEVICES = deviceA
                },
                new T_LINEDOWNEVENTS
                {
                    START_DATE = DateTime.Now.AddHours(3),
                    KOMMENTAR = "Big Problem A-2",
                    LDE_ID = 2,
                    LDD_LDD_ID = 1,
                    END_DATE = DateTime.Now.AddHours(4),
                    T_LINEDOWNDEVICES = deviceA
                },
                new T_LINEDOWNEVENTS
                {
                    START_DATE = DateTime.Now.AddHours(1),
                    KOMMENTAR = "Small Problem B-1",
                    LDE_ID = 3,
                    LDD_LDD_ID = 2,
                    END_DATE = DateTime.Now.AddHours(1.5),
                    T_LINEDOWNDEVICES = deviceB
                },
                new T_LINEDOWNEVENTS
                {
                    START_DATE = DateTime.Now.AddHours(2),
                    KOMMENTAR = "Small Problem B-2",
                    LDE_ID = 4,
                    LDD_LDD_ID = 2,
                    END_DATE = DateTime.Now.AddHours(2.5),
                    T_LINEDOWNDEVICES = deviceB
                }
            };

            // merge events to devices
            foreach (T_LINEDOWNEVENTS ev in Events)
            {
                ev.T_LINEDOWNDEVICES.T_LINEDOWNEVENTS.Add(ev);
            }
        }
    }
}
